/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import QtQuick.Layouts 1.12
import org.kde.kirigami 2.12 as Kirigami
import org.codeberg.dimkard.glossaico 1.0 as Glossaico

AbstractChallengePage {
    id: root

    property var questionChips: challengeData.chips
    property var answerChips: []

    function pushAnswer(pos, val) {
        var answer = root.answerChips
        answer.push(val)
        root.answerChips = answer

        var question = root.questionChips
        question.splice(pos, 1)
        root.questionChips = question
    }

    function pullAnswer(pos, val) {
        var question = root.questionChips
        question.push(val)
        root.questionChips = question

        var answer = root.answerChips
        answer.splice(pos, 1)
        root.answerChips = answer
    }

    challengeItem: columnLayout
    title: qsTr("Tranlsate")

    onAnswerChipsChanged: root.answerGiven = { "answer": answerChips }

    ColumnLayout {
        id: columnLayout

        spacing: Kirigami.Units.largeSpacing
        width: parent.width

        Kirigami.Heading {
            text: qsTr("Tranlsate<b> %1").arg(root.challengeData.meaningInSourceLanguage)
            wrapMode: Text.WordWrap
            bottomPadding: Kirigami.Units.largeSpacing * 2
            leftPadding: Kirigami.Units.largeSpacing

            Layout.fillWidth: true
        }

        Controls.Label {
            id: answerField

            Layout.fillWidth: true

        }

        Flow {
            spacing: Kirigami.Units.largeSpacing

            Repeater {
                model: root.answerChips

                delegate: Controls.Button {
                    text: modelData

                    onClicked: pullAnswer(model.index, modelData)
                }
            }

            Layout.fillWidth: true
        }

        Kirigami.Separator {
            Layout.fillWidth: true
        }

        Flow {
            spacing: Kirigami.Units.largeSpacing


            Repeater {
                model: root.questionChips

                delegate: Controls.Button {
                    text: modelData

                    onClicked: pushAnswer(model.index, modelData)
                }
            }

            Layout.fillWidth: true
        }
    }
}
