/*
 * SPDX-FileCopyrightText: 2022 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.7
import QtQuick.Controls 2.0 as Controls
import QtQuick.Layouts 1.0
import org.kde.kirigami 2.5 as Kirigami


Controls.Control {
    id: root

    property string text
    property list<QtObject> actions
    property color backgroundColor: Kirigami.Theme.backgroundColor
    property color borderColor: Kirigami.Theme.disabledTextColor

    implicitHeight: visible ? contentLayout.implicitHeight + (2 * Kirigami.Units.largeSpacing) : 0

    padding: Kirigami.Units.largeSpacing

    background: Rectangle {
        id: bg

        color: root.backgroundColor
        border.width: 0
        opacity: 0.8
    }

    contentItem: RowLayout {
        id: contentLayout

        Controls.Label {
            id: message

            width: parent.width
            height: parent.height
            leftPadding: Kirigami.Units.smallSpacing
            rightPadding: Kirigami.Units.smallSpacing

            color: Kirigami.Theme.textColor
            wrapMode: Text.WordWrap
            elide: Text.ElideRight
            text: root.text
            verticalAlignment: Text.AlignVCenter
        }

        RowLayout {
            id: actionsLayout

            spacing: Kirigami.Units.largeSpacing

            Layout.fillWidth: true
            Layout.alignment: Qt.AlignRight

            Repeater {
                model: root.actions

                delegate: Controls.Button {
                    visible: modelData.visible
                    action: modelData
                }
            }
        }
    }
}

