/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import QtQuick.Layouts 1.12
import org.kde.kirigami 2.12 as Kirigami
import org.codeberg.dimkard.glossaico 1.0 as Glossaico

Kirigami.ScrollablePage {
    id: root

    property string skillName
    property string skillWordsAndPhrases
    property string skillImage
    property var specialCharacters
    property string targetLanguage
    property string courseName
    property int challengeIndex: 20
    property var challengePage
    property string introduction

    title: skillName

    footer: MessageFooter {
        id: messageFooter

        actions: [
            Kirigami.Action {
                text: qsTr("Back to Skills")

                onTriggered: {
                    QPracticeSessionFlow.endPractice()
                    pageStack.pop()
                }
            },

            Kirigami.Action {
                text: qsTr("Practice %1").arg(root.skillName)

                onTriggered: {
                    if(QPracticeSessionFlow.loadNextChallenge ()) {
                        pageStack.push(challengePageContainer[QPracticeSessionFlow.currentChallengeQuestion.challengeType], {challengeData: QPracticeSessionFlow.currentChallengeQuestion, progress: QPracticeSessionFlow.practiceProgress() })
                    }
                }
            }
        ]
    }

    Connections {
        target: QPracticeSessionFlow

        function onContinueSession() {
            pageStack.pop(root)
            pageStack.push(challengePageContainer[QPracticeSessionFlow.currentChallengeQuestion.challengeType], {challengeData: QPracticeSessionFlow.currentChallengeQuestion, progress: QPracticeSessionFlow.practiceProgress() })
        }

        function onCompleteSession() {
            pageStack.pop(root)
            pageStack.push(challengeCompletePage)
        }
    }

    Component {
        id: challengeCompletePage
        ChallengeCompletePage {
            challengesAnswered: QPracticeSessionFlow.challengesAnswered

            onSessionEnd: {
                pageStack.pop()
                pageStack.removePage(root)
                QPracticeSessionFlow.endPractice()
            }
        }
    }

    ChallengePagesContainer {
        id: challengePageContainer

        targetLanguage: root.targetLanguage
        specialCharacters: root.specialCharacters
        courseName: root.courseName
    }

    ColumnLayout {
        anchors {
            left: parent.left
            right: parent.right
            top: parent.top
        }
        spacing: Kirigami.Units.largeSpacing

        Kirigami.Heading {
            visible: !root.introduction
            text: root.skillName
            wrapMode: Text.WordWrap

            Layout.fillWidth: true
        }

        Controls.Label {
            visible: !root.introduction && root.skillWordsAndPhrases
            text: qsTr("Learn: %1").arg(root.skillWordsAndPhrases)
            wrapMode: Text.WordWrap

            Layout.fillWidth: true
        }

        Text {
            visible: root.introduction
            text: root.introduction
            textFormat: Text.RichText
            wrapMode: Text.WordWrap

            Layout.fillWidth: true
        }
    }
}
