/*
 * SPDX-FileCopyrightText: 2021 Dimitris Kardarakos <dimkard@posteo.net>
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

import QtQuick 2.12
import QtQuick.Controls 2.12 as Controls
import org.kde.kirigami 2.12 as Kirigami
import QtQuick.Layouts 1.12
import org.codeberg.dimkard.glossaico 1.0 as Glossaico

Kirigami.ApplicationWindow
{
    id: root

    property var latestDataInfo

    width: Kirigami.Units.gridUnit * 30

    globalDrawer: LLMGlobalDrawer {
        courses: coursesView
        pageStack: root.pageStack
        handleVisible: pageStack.currentItem && pageStack.currentItem.hasOwnProperty("showGlobalHandle") && pageStack.currentItem.showGlobalHandle
    }

    contextDrawer: Kirigami.ContextDrawer {}

    pageStack {
        defaultColumnWidth: Kirigami.Units.gridUnit * 40
        initialPage: QCourseUpdateManager.canUpdate() ? dataLoadPage : coursesView
    }

    Component {
        id: coursesView

        CoursesView {
            onCourseLoaded: {
                pageStack.clear()
                pageStack.push(modulesView, {course: courseData})
            }
        }
    }

    Component {
        id: modulesView

        ModulesView {}
    }

    Component {
        id: dataLoadPage

        DataLoadPage {
            onDataLoadCompleted: {
                pageStack.clear()
                pageStack.push(coursesView)
            }
        }
    }

    Item {
        states: [
            State {
                name: ""
                PropertyChanges {target: pageStack; globalToolBar.style: Kirigami.ApplicationHeaderStyle.Auto}
                PropertyChanges {target: pageStack; interactive: true}
            },
            State {
                name: "prevent-navigation"
                when: QPracticeSessionFlow.practicing
                PropertyChanges {target: pageStack; globalToolBar.style: Kirigami.ApplicationHeaderStyle.None}
                PropertyChanges {target: pageStack; interactive: false}
                PropertyChanges {target: pageStack; defaultColumnWidth: root.width}
            }
        ]
    }
}
